# doc/README.md

A testfile should not be generated from this file
since there are no Python fenced code blocks.

Here are some other fenced code blocks.

```ini
# pytest.ini and tox.ini
[pytest]
addopts = --phmdoctest
```
```ini
# setup.cfg
[tool:pytest]
addopts = --phmdoctest
```
```toml
# pyproject.toml
[tool.pytest.ini_options]
addopts = "--phmdoctest"
```
